@@ -11,7 +11,7 @@ use Test2::Harness::Util::UUID qw/gen_uuid/;
 
 use Test2::Harness::Util qw/mod2file/;
 
-our $VERSION = '0.000037';
+our $VERSION = '0.000038';
 
 use parent 'Test2::Harness::Renderer';
 use Test2::Harness::Util::HashBase qw{
@@ -43,7 +43,7 @@ sub init {
             my $file = mod2file($cmod);
             require $file;
 
-            $config = $cmod->yath_ui_config(%$db);
+            $config = $cmod->yath_ui_config(%$$db);
         }
         else {
             my $dsn = $db->dsn;
